PyBaccarat: pybaccarat.baccaratsystems.EZDragon Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | Public Attributes | List of all members
pybaccarat.baccaratsystems.EZDragon Class Reference

Card count system for EZ-Baccarat Dragon side bet. More...

Inheritance diagram for pybaccarat.baccaratsystems.EZDragon:

## Public Member Functions
def | __init__ (self)
| TBD.
def | add_count (self, card_rank)
| Local routine to add a card to the count.
def | new_shoe (self, burn_card)
| Start of a new shoe. More...
def | hand_pre (self, hand_num)
def | hand_post (self, win_diff, player, banker)
| This is the result of a hand being played. More...
def | end_shoe (self)
| End of shoe. More...
def | __init__ (self)
| TBD.
def | add_count (self, card_rank)
| Local routine to add a card to the count.
def | new_shoe (self, burn_card)
| Start of a new shoe. More...
def | hand_pre (self, hand_num)
def | hand_post (self, win_diff, player, banker)
| This is the result of a hand being played. More...
def | end_shoe (self)
| End of shoe. More...

## Public Attributes
| play_w
| play_l
| count
| hand_number

## Detailed Description

Card count system for EZ-Baccarat Dragon side bet.

EZ-Baccarat is the shuffle master commission free game. The Dragon side bet pays 40 to 1 for a banker win of 3 card totalling 7.

## Member Function Documentation

## ◆ end_shoe() [1/2]

def pybaccarat.baccaratsystems.EZDragon.end_shoe | ( |  | self | ) |

End of shoe.

Show results.

## ◆ end_shoe() [2/2]

def pybaccarat.baccaratsystems.EZDragon.end_shoe | ( |  | self | ) |

End of shoe.

Show results.

## ◆ hand_post() [1/2]

def pybaccarat.baccaratsystems.EZDragon.hand_post | ( |  | self,
|  |  | win_diff,
|  |  | player,
|  |  | banker
| ) |  |

This is the result of a hand being played.

Parameters

  hand_number | int
  win_diff | TBD? win('BPT') and diff('n' or '0'..'9')
  player | Hand player hand just played
  banker | Hand banker hand just played

Returns
  String for display purposes

## ◆ hand_post() [2/2]

def pybaccarat.baccaratsystems.EZDragon.hand_post | ( |  | self,
|  |  | win_diff,
|  |  | player,
|  |  | banker
| ) |  |

This is the result of a hand being played.

Parameters

  hand_number | int
  win_diff | TBD? win('BPT') and diff('n' or '0'..'9')
  player | Hand player hand just played
  banker | Hand banker hand just played

Returns
  String for display purposes

## ◆ new_shoe() [1/2]

def pybaccarat.baccaratsystems.EZDragon.new_shoe | ( |  | self,
|  |  | burn_card
| ) |  |

Start of a new shoe.

Start the new count. The burn card is exposed so we can record that as an initial value.

Parameters

  <em>burn_rank</em> | is the rank of the burn card. Add it to the count.

## ◆ new_shoe() [2/2]

def pybaccarat.baccaratsystems.EZDragon.new_shoe | ( |  | self,
|  |  | burn_card
| ) |  |

Start of a new shoe.

Start the new count. The burn card is exposed so we can record that as an initial value.

Parameters

  <em>burn_rank</em> | is the rank of the burn card. Add it to the count.

The documentation for this class was generated from the following file:

- build/lib/pybaccarat/baccaratsystems.py